@@ -22,4 +22,6 @@ class TestInit:
         # teardown_class() after any methods in this class
 
     def test__jupyter_server_extension_paths(self):
-        assert _jupyter_server_extension_paths() == [{"module": "jupyterlab_autoversion.extension"}]
+        assert _jupyter_server_extension_paths() == [
+            {"module": "jupyterlab_autoversion.extension"}
+        ]
